==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'ចំពោះ​តែ អត្ថបទ​អនាគត (គ្មាន​សកម្មភាព ​លើ​ឃ្លាំងទិន្នន័យ​)។',
	'bouton_radio_articles_tous' => 'ចំពោះគ្រប់​អត្ថបទ គ្មានលើកលែង។',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ចំពោះគ្រប់​អត្ថបទ, លើកលែងអត្ថបទ ​ដែលវេទិកា​លែងសកម្ម។',
	'bouton_radio_enregistrement_obligatoire' => 'តំរូវអោយ​ចុះបញ្ជី​  (ពួក​អ្នក​ប្រើប្រាស់​ ត្រូវតែ​ជាវប្រចាំ​ដោយ​ផ្ដល់​ អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​ពួកគេ មុននឹងអាច ​ដាក់​ការរួមចំណែក​)។',
	'bouton_radio_moderation_priori' => 'សំរបសំរួល ជាដំបូង (​ការរួមចំណែក បង្ហាញចេញ សាធារណៈ តែបន្ទាប់ពី ការផ្តល់សុពលភាព ដោយអ្នកអភិបាល)។', # MODIF
	'bouton_radio_modere_abonnement' => 'ផ្អែកលើ ការជាវប្រចាំ',
	'bouton_radio_modere_posteriori' => 'សំរបសំរួល ពេលបន្ទាប់', # MODIF
	'bouton_radio_modere_priori' => 'សំរបសំរួល ជាដំបូង', # MODIF
	'bouton_radio_publication_immediate' => 'ការផ្សព្វ​ផ្សាយ​​បន្ទាន់ នៃសារ (​ការរួមចំណែក ​បង្ហាញ​ចេញ ពេល​ផ្ញើពួកវា, ពួកអ្នកអភិបាល អាចលុបចេញ ពួកវា​ ពេលបន្ទាប់)។',

	// D
	'documents_interdits_forum' => 'ឯកសារហាម ក្នុងវេទិកា',

	// F
	'form_pet_message_commentaire' => 'មួយសារ មួយវិចារ ឬ ?',
	'forum' => 'វេទិកា',
	'forum_acces_refuse' => 'អ្នក​គ្មានអាចទៀត ចូលទៅ វេទិកា​ទាំងនេះ។',
	'forum_attention_dix_caracteres' => '<b>​ប្រយ័ត្ន !</b> សារ ​របស់​អ្នក ត្រូវtE​មាន​ប្រវែង​យ៉ាងតិច ១០ អក្សរ។',
	'forum_attention_trois_caracteres' => '<b>​ប្រយ័ត្ន !</b> ចំណងជើង ​របស់​អ្នក ត្រូវ​តែមាន​ប្រវែង​យ៉ាងតិច ៣ អក្សរ។',
	'forum_attention_trop_caracteres' => '<b>​ប្រយ័ត្ន​ !</b> សារ​របស់​អ្នក ​វែង​ពេក (@compte@ ​អក្សរ​) ៖ ដើម្បី​អាចត្រូវបាន​រក្សា​វា​ទុក, វាមិនត្រូវ លើសពី @max@ អក្សរ​។', # MODIF
	'forum_avez_selectionne' => 'អ្នក​បាន ​ជ្រើសយក ៖',
	'forum_cliquer_retour' => 'ចុច <a href=\'@retour_forum@\'>ទី​នេះ​</a> ដើម្បី​បន្ដ ។',
	'forum_forum' => 'វេទិកា',
	'forum_info_modere' => 'វេទិកា​នេះ​ ត្រូវ​បានសំរបសំរួល ​ជាដំបូង ៖ ការរួម​ចំណែក របស់​អ្នក ​នឹង​លេច​ចេញ​ តែ​បន្ទាប់ពី​ត្រូវ​បាន​​មានសុពលភាព ​ដោយ​អ្នកអភិបាលសៃថ៍។', # MODIF
	'forum_lien_hyper' => '<b>តំណភ្ជាប់ ខ្ពស់</b> (​ជា​ជំរើស​)', # MODIF
	'forum_message_definitif' => 'សារ​ បញ្ចប់៖ ផ្ញើ​ទៅ​វ៉ែបសៃថ៍',
	'forum_message_trop_long' => 'សារ​ របស់​អ្នក ​វែង​ពេក ។ ប្រវែង​អតិបរមា ត្រឹម ២០០០០ អក្សរ។', # MODIF
	'forum_ne_repondez_pas' => 'កុំ​ឆ្លើយ​ទៅ ​មែ​វល៍​នេះ ប៉ុន្ដែ​ លើ​វេទិកា តាម​អាសយដ្ឋាន​ខាងក្រោម៖', # MODIF
	'forum_page_url' => '(​បើ​សារ​ របស់​អ្នក ​យោងទៅ មួយអត្ថបទ​ដែល​បាន​ផ្សព្វផ្សាយលើ​វ៉ែបសៃថ៍ ឬ នៅទំព័រ ​ដែល​ផ្ដល់​​ពត៌មាន​បន្ថែម, បញ្ចូល​បន្ទាប់នេះ ចំណងជើង​ទំព័រ និង អាសយដ្ឋាន URL របស់វា។)',
	'forum_poste_par' => 'បានដាក់សារ ដោយ @parauteur@ បន្ទាប់​ពី​អត្ថបទ​ "@titre@"។', # MODIF
	'forum_qui_etes_vous' => 'អ្នកជា អ្នកណា? </b> (​ជា ជំរើស​)', # MODIF
	'forum_texte' => '​សារ ​របស់​អ្នក៖', # MODIF
	'forum_titre' => 'ចំណងជើង៖', # MODIF
	'forum_url' => 'URL៖', # MODIF
	'forum_valider' => 'ធ្វើ​អោយ​សុពលភាព ជំរើស នេះ',
	'forum_voir_avant' => 'មើល​សារនេះ ​មុននឹងដាក់ប្រកាសវា', # MODIF
	'forum_votre_email' => 'អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​អ្នក៖', # MODIF
	'forum_votre_nom' => 'ឈ្មោះ (​ឬ​ ឈ្មោះ​ហៅ​ក្រៅ​) របស់​អ្នក៖', # MODIF
	'forum_vous_enregistrer' => 'ដើម្បី​ចូលរួម ​វេទិកា​នេះ, អ្នក​ត្រូវតែជាដំបូង ​ចុះ​ឈ្មោះ​។ អរគុណ​ ដែល​បញ្ចូល​អត្តសញ្ញា​ផ្ទាល់ខ្លួន​ ដែលត្រូវ​បាន​ផ្ដល់​ជូន​អ្នក។ បើ​អ្នក​មិន​ទាន់​ចុះ​ឈ្មោះ​, អ្នក​ត្រូវតែ',
	'forum_vous_inscrire' => 'ចុះ​ឈ្មោះ អ្នក។',

	// I
	'icone_poster_message' => 'ផ្ញើ​សារ',
	'icone_suivi_forum' => 'តាមដាន​វេទិកាសាធារណៈ ៖ @nb_forums@ contribution(s)',
	'icone_suivi_forums' => 'តាមដាន/គ្រប់គ្រង ​វេទិកានានា',
	'icone_supprimer_message' => 'លុប​ចេញ សារ​នេះ',
	'icone_valider_message' => 'ធ្វើ​អោយ​សុពលភាព សារ​នេះ',
	'info_activer_forum_public' => '<i>ដើម្បីសកម្ម ទីប្រជុំសាធារណះ, សូមជ្រើសរើស បែបសំរបសំរួល របស់ពួកវា ជាលំនាំដើម៖</i>', # MODIF
	'info_appliquer_choix_moderation' => 'អនុវត្ត ការជ្រើសរើស បែបសំរបសំរួល នេះ ៖',
	'info_config_forums_prive_admin' => 'មួយទីប្រជុំមតិ ត្រូវបានទុក សំរាប់ ពួកអ្នកអភិបាលសៃថ៍៖',
	'info_config_forums_prive_global' => 'ទីប្រជុំមតិរួម, បើកទៅគ្រប់អ្នកនិពន្ធ៖',
	'info_desactiver_forum_public' => 'ធ្វើ្វ​អោយ​វេទិកាសាធារណៈ​លែង​ប្រើប្រាស់​បាន ។ វេទិកាសាធារណៈ​អាច​ត្រូវ​បាន​អនុញ្ញាត​ដោយ​ឈរ​លើ​មូលដ្ឋាន​មួយ​ករណី​ម្ដងៗ​សម្រាប់​អត្ថបទ ។ វេទិការ​នោះ​នឹង​ត្រូវ​ហាមឃាត់​សម្រាប់​ផ្នែក ព័ត៌មាន​នេះ ។​ល​។',
	'info_envoi_forum' => ' ផ្ញើ​វេទិកា​ទៅ​អ្នកនិពន្ធ​អត្ថបទ',
	'info_fonctionnement_forum' => 'ប្រតិបត្ដិការ​វេទិកា ៖',
	'info_gauche_suivi_forum_2' => 'ទំព័រ <i>តាមដាន ទីប្រជុំមតិ</i> ជា មួយឧបករគ្រប់គ្រង នៃវ៉ែបសៃថ៍ របស់អ្នក (និង មិនជា ធ្លាពិភាក្សា ឬ​ ធ្លាបោះផ្សាយ​)។ វា បង្ហាញ គ្រប់ការរួមចំណែក របស់ទីប្រជុំមតិសាធារណះ នៃអត្ថបទនេះ និងអនុញ្ញាតអ្នក គ្រប់គ្រង ការរួមចំណែក ទាំងនេះ។', # MODIF
	'info_liens_syndiques_3' => 'វេទិកា',
	'info_liens_syndiques_4' => 'គឺ',
	'info_liens_syndiques_5' => 'វេទិកា',
	'info_liens_syndiques_6' => 'គឺ',
	'info_liens_syndiques_7' => 'ការ​រង់ចាំ​ការ​បញ្ជាក់់',
	'info_mode_fonctionnement_defaut_forum_public' => 'បែបការងារលំនាំដើម នៃទីប្រជុំមតិសាធារណះ',
	'info_option_email' => 'ពេល មួយទស្សនាករ នៃសៃថ៍ ដាក់មួយវិចារ ក្នុងទីប្រជុំមតិ ទាក់ទិនមួយអត្ថបទ, ពួកអ្នកនិពន្ធ នៃអត្ថបទ អាចត្រូវបានប្រាប់ដំណឹង ពីវិចារនេះ តាមអ៊ីមែវល៍។ បើអ្នក ត្រូវប្រើប្រាស់ ជំរើសខាងលើ, បង្ហាញ សំរាប់ ប្រភេទទីប្រជុំមតិ នីមួយ។',
	'info_pas_de_forum' => 'គ្មាន​វេទិកា',
	'item_activer_forum_administrateur' => 'សកម្ម វេទិកា នៃអ្នកអភិបាល',
	'item_config_forums_prive_global' => 'ធ្វើអោយសកម្ម ទីប្រជុំមតិ នៃពួកអ្នកនិពន្ធ',
	'item_config_forums_prive_objets' => 'ធ្វើអោយសកម្ម ទីប្រជុំមតិ ទាំងនេះ',
	'item_desactiver_forum_administrateur' => 'បិទ​មុខងារ​វេទិកា​ក្រុម​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ',
	'item_non_config_forums_prive_global' => 'ធ្វើអោយអសកម្ម ទីប្រជុំមតិ នៃពួកអ្នកនិពន្ធ',
	'item_non_config_forums_prive_objets' => 'ធ្វើអោយអសកម្ម ទីប្រជុំមតិទាំងនេះ',

	// L
	'lien_reponse_article' => 'ចំលើយ ទៅ​អត្ថបទ',
	'lien_reponse_breve_2' => 'ចំលើយ ទៅ​ពត៌មានខ្លី',
	'lien_reponse_rubrique' => 'ចំលើយ ទៅផ្នែក',
	'lien_reponse_site_reference' => 'ចំលើយ ទៅវ៉ែបសៃថ៍យោង៖', # MODIF

	// O
	'onglet_messages_internes' => 'សារ​ខាងក្នុង',
	'onglet_messages_publics' => 'សារ​សាធារណៈ',
	'onglet_messages_vide' => 'សារ​គ្មាន​អត្ថបទ',

	// R
	'repondre_message' => 'ឆ្លើយ​តប​ ទៅ​សារ​នេះ',

	// S
	'statut_original' => 'ភាពដើម',

	// T
	'titre_cadre_forum_administrateur' => 'វេទិកា​ឯកជន​របស់​ក្រុម​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ',
	'titre_cadre_forum_interne' => 'ទីប្រជុំមតិ ខាងក្នុង',
	'titre_forum' => 'វេទិកា',
	'titre_forum_suivi' => 'ការ​តាមដាន​វេទិកា',
	'titre_page_forum_suivi' => 'ការ​តាមដាន​វេទិកា'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=km
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'ចំពោះ​តែ អត្ថបទ​អនាគត (គ្មាន​សកម្មភាព ​លើ​ឃ្លាំងទិន្នន័យ​)។',
	'bouton_radio_articles_tous' => 'ចំពោះគ្រប់​អត្ថបទ គ្មានលើកលែង។',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ចំពោះគ្រប់​អត្ថបទ, លើកលែងអត្ថបទ ​ដែលវេទិកា​លែងសកម្ម។',
	'bouton_radio_enregistrement_obligatoire' => 'តំរូវអោយ​ចុះបញ្ជី​  (ពួក​អ្នក​ប្រើប្រាស់​ ត្រូវតែ​ជាវប្រចាំ​ដោយ​ផ្ដល់​ អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​ពួកគេ មុននឹងអាច ​ដាក់​ការរួមចំណែក​)។',
	'bouton_radio_moderation_priori' => 'សំរបសំរួល ជាដំបូង (​ការរួមចំណែក បង្ហាញចេញ សាធារណៈ តែបន្ទាប់ពី ការផ្តល់សុពលភាព ដោយអ្នកអភិបាល)។', # MODIF
	'bouton_radio_modere_abonnement' => 'ផ្អែកលើ ការជាវប្រចាំ',
	'bouton_radio_modere_posteriori' => 'សំរបសំរួល ពេលបន្ទាប់', # MODIF
	'bouton_radio_modere_priori' => 'សំរបសំរួល ជាដំបូង', # MODIF
	'bouton_radio_publication_immediate' => 'ការផ្សព្វ​ផ្សាយ​​បន្ទាន់ នៃសារ (​ការរួមចំណែក ​បង្ហាញ​ចេញ ពេល​ផ្ញើពួកវា, ពួកអ្នកអភិបាល អាចលុបចេញ ពួកវា​ ពេលបន្ទាប់)។',

	// D
	'documents_interdits_forum' => 'ឯកសារហាម ក្នុងវេទិកា',

	// F
	'form_pet_message_commentaire' => 'មួយសារ មួយវិចារ ឬ ?',
	'forum' => 'វេទិកា',
	'forum_acces_refuse' => 'អ្នក​គ្មានអាចទៀត ចូលទៅ វេទិកា​ទាំងនេះ។',
	'forum_attention_dix_caracteres' => '<b>​ប្រយ័ត្ន !</b> សារ ​របស់​អ្នក ត្រូវtE​មាន​ប្រវែង​យ៉ាងតិច ១០ អក្សរ។',
	'forum_attention_trois_caracteres' => '<b>​ប្រយ័ត្ន !</b> ចំណងជើង ​របស់​អ្នក ត្រូវ​តែមាន​ប្រវែង​យ៉ាងតិច ៣ អក្សរ។',
	'forum_attention_trop_caracteres' => '<b>​ប្រយ័ត្ន​ !</b> សារ​របស់​អ្នក ​វែង​ពេក (@compte@ ​អក្សរ​) ៖ ដើម្បី​អាចត្រូវបាន​រក្សា​វា​ទុក, វាមិនត្រូវ លើសពី @max@ អក្សរ​។', # MODIF
	'forum_avez_selectionne' => 'អ្នក​បាន ​ជ្រើសយក ៖',
	'forum_cliquer_retour' => 'ចុច <a href=\'@retour_forum@\'>ទី​នេះ​</a> ដើម្បី​បន្ដ ។',
	'forum_forum' => 'វេទិកា',
	'forum_info_modere' => 'វេទិកា​នេះ​ ត្រូវ​បានសំរបសំរួល ​ជាដំបូង ៖ ការរួម​ចំណែក របស់​អ្នក ​នឹង​លេច​ចេញ​ តែ​បន្ទាប់ពី​ត្រូវ​បាន​​មានសុពលភាព ​ដោយ​អ្នកអភិបាលសៃថ៍។', # MODIF
	'forum_lien_hyper' => '<b>តំណភ្ជាប់ ខ្ពស់</b> (​ជា​ជំរើស​)', # MODIF
	'forum_message_definitif' => 'សារ​ បញ្ចប់៖ ផ្ញើ​ទៅ​វ៉ែបសៃថ៍',
	'forum_message_trop_long' => 'សារ​ របស់​អ្នក ​វែង​ពេក ។ ប្រវែង​អតិបរមា ត្រឹម ២០០០០ អក្សរ។', # MODIF
	'forum_ne_repondez_pas' => 'កុំ​ឆ្លើយ​ទៅ ​មែ​វល៍​នេះ ប៉ុន្ដែ​ លើ​វេទិកា តាម​អាសយដ្ឋាន​ខាងក្រោម៖', # MODIF
	'forum_page_url' => '(​បើ​សារ​ របស់​អ្នក ​យោងទៅ មួយអត្ថបទ​ដែល​បាន​ផ្សព្វផ្សាយលើ​វ៉ែបសៃថ៍ ឬ នៅទំព័រ ​ដែល​ផ្ដល់​​ពត៌មាន​បន្ថែម, បញ្ចូល​បន្ទាប់នេះ ចំណងជើង​ទំព័រ និង អាសយដ្ឋាន URL របស់វា។)',
	'forum_poste_par' => 'បានដាក់សារ ដោយ @parauteur@ បន្ទាប់​ពី​អត្ថបទ​ "@titre@"។', # MODIF
	'forum_qui_etes_vous' => 'អ្នកជា អ្នកណា? </b> (​ជា ជំរើស​)', # MODIF
	'forum_texte' => '​សារ ​របស់​អ្នក៖', # MODIF
	'forum_titre' => 'ចំណងជើង៖', # MODIF
	'forum_url' => 'URL៖', # MODIF
	'forum_valider' => 'ធ្វើ​អោយ​សុពលភាព ជំរើស នេះ',
	'forum_voir_avant' => 'មើល​សារនេះ ​មុននឹងដាក់ប្រកាសវា', # MODIF
	'forum_votre_email' => 'អាសយដ្ឋាន​អ៊ីមែវល៍ ​របស់​អ្នក៖', # MODIF
	'forum_votre_nom' => 'ឈ្មោះ (​ឬ​ ឈ្មោះ​ហៅ​ក្រៅ​) របស់​អ្នក៖', # MODIF
	'forum_vous_enregistrer' => 'ដើម្បី​ចូលរួម ​វេទិកា​នេះ, អ្នក​ត្រូវតែជាដំបូង ​ចុះ​ឈ្មោះ​។ អរគុណ​ ដែល​បញ្ចូល​អត្តសញ្ញា​ផ្ទាល់ខ្លួន​ ដែលត្រូវ​បាន​ផ្ដល់​ជូន​អ្នក។ បើ​អ្នក​មិន​ទាន់​ចុះ​ឈ្មោះ​, អ្នក​ត្រូវតែ',
	'forum_vous_inscrire' => 'ចុះ​ឈ្មោះ អ្នក។',

	// I
	'icone_poster_message' => 'ផ្ញើ​សារ',
	'icone_suivi_forum' => 'តាមដាន​វេទិកាសាធារណៈ ៖ @nb_forums@ contribution(s)',
	'icone_suivi_forums' => 'តាមដាន/គ្រប់គ្រង ​វេទិកានានា',
	'icone_supprimer_message' => 'លុប​ចេញ សារ​នេះ',
	'icone_valider_message' => 'ធ្វើ​អោយ​សុពលភាព សារ​នេះ',
	'info_activer_forum_public' => '<i>ដើម្បីសកម្ម ទីប្រជុំសាធារណះ, សូមជ្រើសរើស បែបសំរបសំរួល របស់ពួកវា ជាលំនាំដើម៖</i>', # MODIF
	'info_appliquer_choix_moderation' => 'អនុវត្ត ការជ្រើសរើស បែបសំរបសំរួល នេះ ៖',
	'info_config_forums_prive_admin' => 'មួយទីប្រជុំមតិ ត្រូវបានទុក សំរាប់ ពួកអ្នកអភិបាលសៃថ៍៖',
	'info_config_forums_prive_global' => 'ទីប្រជុំមតិរួម, បើកទៅគ្រប់អ្នកនិពន្ធ៖',
	'info_desactiver_forum_public' => 'ធ្វើ្វ​អោយ​វេទិកាសាធារណៈ​លែង​ប្រើប្រាស់​បាន ។ វេទិកាសាធារណៈ​អាច​ត្រូវ​បាន​អនុញ្ញាត​ដោយ​ឈរ​លើ​មូលដ្ឋាន​មួយ​ករណី​ម្ដងៗ​សម្រាប់​អត្ថបទ ។ វេទិការ​នោះ​នឹង​ត្រូវ​ហាមឃាត់​សម្រាប់​ផ្នែក ព័ត៌មាន​នេះ ។​ល​។',
	'info_envoi_forum' => ' ផ្ញើ​វេទិកា​ទៅ​អ្នកនិពន្ធ​អត្ថបទ',
	'info_fonctionnement_forum' => 'ប្រតិបត្ដិការ​វេទិកា ៖',
	'info_gauche_suivi_forum_2' => 'ទំព័រ <i>តាមដាន ទីប្រជុំមតិ</i> ជា មួយឧបករគ្រប់គ្រង នៃវ៉ែបសៃថ៍ របស់អ្នក (និង មិនជា ធ្លាពិភាក្សា ឬ​ ធ្លាបោះផ្សាយ​)។ វា បង្ហាញ គ្រប់ការរួមចំណែក របស់ទីប្រជុំមតិសាធារណះ នៃអត្ថបទនេះ និងអនុញ្ញាតអ្នក គ្រប់គ្រង ការរួមចំណែក ទាំងនេះ។', # MODIF
	'info_liens_syndiques_3' => 'វេទិកា',
	'info_liens_syndiques_4' => 'គឺ',
	'info_liens_syndiques_5' => 'វេទិកា',
	'info_liens_syndiques_6' => 'គឺ',
	'info_liens_syndiques_7' => 'ការ​រង់ចាំ​ការ​បញ្ជាក់់',
	'info_mode_fonctionnement_defaut_forum_public' => 'បែបការងារលំនាំដើម នៃទីប្រជុំមតិសាធារណះ',
	'info_option_email' => 'ពេល មួយទស្សនាករ នៃសៃថ៍ ដាក់មួយវិចារ ក្នុងទីប្រជុំមតិ ទាក់ទិនមួយអត្ថបទ, ពួកអ្នកនិពន្ធ នៃអត្ថបទ អាចត្រូវបានប្រាប់ដំណឹង ពីវិចារនេះ តាមអ៊ីមែវល៍។ បើអ្នក ត្រូវប្រើប្រាស់ ជំរើសខាងលើ, បង្ហាញ សំរាប់ ប្រភេទទីប្រជុំមតិ នីមួយ។',
	'info_pas_de_forum' => 'គ្មាន​វេទិកា',
	'item_activer_forum_administrateur' => 'សកម្ម វេទិកា នៃអ្នកអភិបាល',
	'item_config_forums_prive_global' => 'ធ្វើអោយសកម្ម ទីប្រជុំមតិ នៃពួកអ្នកនិពន្ធ',
	'item_config_forums_prive_objets' => 'ធ្វើអោយសកម្ម ទីប្រជុំមតិ ទាំងនេះ',
	'item_desactiver_forum_administrateur' => 'បិទ​មុខងារ​វេទិកា​ក្រុម​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ',
	'item_non_config_forums_prive_global' => 'ធ្វើអោយអសកម្ម ទីប្រជុំមតិ នៃពួកអ្នកនិពន្ធ',
	'item_non_config_forums_prive_objets' => 'ធ្វើអោយអសកម្ម ទីប្រជុំមតិទាំងនេះ',

	// L
	'lien_reponse_article' => 'ចំលើយ ទៅ​អត្ថបទ',
	'lien_reponse_breve_2' => 'ចំលើយ ទៅ​ពត៌មានខ្លី',
	'lien_reponse_rubrique' => 'ចំលើយ ទៅផ្នែក',
	'lien_reponse_site_reference' => 'ចំលើយ ទៅវ៉ែបសៃថ៍យោង៖', # MODIF

	// O
	'onglet_messages_internes' => 'សារ​ខាងក្នុង',
	'onglet_messages_publics' => 'សារ​សាធារណៈ',
	'onglet_messages_vide' => 'សារ​គ្មាន​អត្ថបទ',

	// R
	'repondre_message' => 'ឆ្លើយ​តប​ ទៅ​សារ​នេះ',

	// S
	'statut_original' => 'ភាពដើម',

	// T
	'titre_cadre_forum_administrateur' => 'វេទិកា​ឯកជន​របស់​ក្រុម​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ',
	'titre_cadre_forum_interne' => 'ទីប្រជុំមតិ ខាងក្នុង',
	'titre_forum' => 'វេទិកា',
	'titre_forum_suivi' => 'ការ​តាមដាន​វេទិកា',
	'titre_page_forum_suivi' => 'ការ​តាមដាន​វេទិកា',
];
